pub enum NetworkKind {
Mainnet,
Testnet,
Regtest,
}Expand description
An enum describing the kind of network, whether it’s the production mainnet or a testnet.
Variants
Implementations
Sourceimpl NetworkKind
impl NetworkKind
Sourcepub fn b58_pubkey_address_prefix(self) -> [u8; 2]
pub fn b58_pubkey_address_prefix(self) -> [u8; 2]
Returns the human-readable prefix for Base58Check-encoded transparent pay-to-public-key-hash payment addresses for the network.
Sourcepub fn b58_script_address_prefix(self) -> [u8; 2]
pub fn b58_script_address_prefix(self) -> [u8; 2]
Returns the human-readable prefix for Base58Check-encoded transparent pay-to-script-hash payment addresses for the network.
Sourcepub fn bip70_network_name(&self) -> String
pub fn bip70_network_name(&self) -> String
Return the network name as defined in BIP70
Sourcepub fn tex_address_prefix(self) -> [u8; 2]
pub fn tex_address_prefix(self) -> [u8; 2]
Returns the 2 bytes prefix for Bech32m-encoded transparent TEX payment addresses for the network as defined in ZIP-320.